# ElementRequest

Adds nested create feature

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** | IFC type for the element | 
**uuid** | **str** |  | [optional] 
**attributes** | [**PropertySetRequest**](PropertySetRequest.md) |  | [optional] 
**property_sets** | [**[PropertySetRequest]**](PropertySetRequest.md) |  | [optional] 
**classifications** | [**[ClassificationRequest]**](ClassificationRequest.md) |  | [optional] 
**layers** | [**[LayerElementRequest]**](LayerElementRequest.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


